@@ -15,6 +15,7 @@
 #include <KDesktopFile>
 
 #include <QDebug>
+#include <QFile>
 #include <QQmlContext>
 #include <QQmlExpression>
 #include <QQmlProperty>
@@ -57,7 +58,7 @@ QList<KPluginMetaData> WallpaperInterface::listWallpaperMetadataForMimetype(cons
         if (!formFactor.isEmpty() && !md.value(QStringLiteral("X-Plasma-FormFactors")).contains(formFactor)) {
             return false;
         }
-        return KPluginMetaData::readStringList(md.rawData(), QStringLiteral("X-Plasma-DropMimeTypes")).contains(mimetype);
+        return md.value(QStringLiteral("X-Plasma-DropMimeTypes"), QStringList()).contains(mimetype);
     };
     return KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Wallpaper"), QString(), filter);
 }
@@ -114,17 +115,20 @@ void WallpaperInterface::syncWallpaperPackage()
     }
 
     m_actions->clear();
-    m_pkg = Plasma::PluginLoader::self()->loadPackage(QStringLiteral("Plasma/Wallpaper")).kPackage();
+    setProperty("contextualActions", QVariant::fromValue(contextualActions()));
+    m_pkg = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Wallpaper"));
     m_pkg.setPath(m_wallpaperPlugin);
     if (!m_pkg.isValid()) {
         qWarning() << "Error loading the wallpaper, no valid package loaded";
         return;
     }
 
-    if (m_configLoader)
+    if (m_configLoader) {
         m_configLoader->deleteLater();
-    if (m_configuration)
+    }
+    if (m_configuration) {
         m_configuration->deleteLater();
+    }
     m_configLoader = nullptr;
     m_configuration = nullptr;
     if (configScheme()) {
@@ -182,7 +186,7 @@ QList<QAction *> WallpaperInterface::contextualActions() const
 
 bool WallpaperInterface::supportsMimetype(const QString &mimetype) const
 {
-    return KPluginMetaData::readStringList(m_pkg.metadata().rawData(), QStringLiteral("X-Plasma-DropMimeTypes")).contains(mimetype);
+    return m_pkg.metadata().value(QStringLiteral("X-Plasma-DropMimeTypes"), QStringList()).contains(mimetype);
 }
 
 void WallpaperInterface::setUrl(const QUrl &url)
@@ -226,7 +230,6 @@ void WallpaperInterface::removeAction(const QString &name)
 
     if (action) {
         m_actions->removeAction(action);
-        delete action;
     }
     setProperty("contextualActions", QVariant::fromValue(contextualActions()));
 }
